@@ -8,10 +8,14 @@ class Database_Handler:
     def __build_connection(self, user_name, password, host, port, database):
         self.handler = pg_handler(user_name, password, host, port, database)
     
-    def add_sql_props(self, columns, keywords, base_query):
+    def add_sql_props(self, columns, keywords, table_name):
         self.handler.define_columns(columns)
-        self.handler.set_base_query(base_query)
+        self.handler.set_table_name(table_name)
         self.handler.set_keywords(keywords)
     
     def search_records(self):
-        return self.handler.search_for_records()
\ No newline at end of file
+        return self.handler.search_for_records()
+    
+    def insert_record(self, keywords):
+        return self.handler.insert_row(keywords)
+    
\ No newline at end of file
