@@ -10,14 +10,15 @@ class Postgres_Handler(Sql_Handler):
         self.host = host
         self.port = port
         self.database = database
+        
     #Methods from inherited abstract class
     def define_columns(self, columns):
         super().define_columns(columns)
     
-    def set_base_query(self, base_query):
-        return super().set_base_query(base_query)
+    def set_table_name(self, table_name):
+        return super().set_table_name(table_name)
         
-    def set_keywords(self, keywords):
+    def set_keywords(self, keywords): 
         return super().set_keywords(keywords)
    
     # Used internally create to run query
@@ -55,33 +56,23 @@ class Postgres_Handler(Sql_Handler):
         
     #Select all rows 
     def search_for_records(self):
-        #try:
-            payload = {}
-        
-            query_value_list = self.__build_search_query()       
-            print(f'\n{query_value_list}\n')
-        
-
-            #Runs the query and returns the results
-            results = self.__run_query(query_value_list[0], query_value_list[1])
-       
-            status = results[0]
-            
-                
-            payload = self.__format_search_results(results)
-        
-            return payload
-        #except Exception as ex:
-            return f"Exception: {ex}"
+        payload = {}
     
+        query_value_list = self.__build_search_query()       
+
+        #Runs the query and returns the results
+        results = self.__run_query(query_value_list[0], query_value_list[1])
+        payload = self.__format_search_results(results)
+    
+        return payload
+
     def __build_search_query(self):
         where_string = ''
         values_dict = {}
         
         #Start of query string
-        query = self.base_query
-        
-        #Empty string for building the where clause of the query
+        query = f"SELECT * FROM %(table_name)s"
+        values_dict['table_name'] = self.table_name
         
         #Keys for the StartDate and EndDate
         start_date_key = "SearchStartDate"
@@ -114,7 +105,7 @@ class Postgres_Handler(Sql_Handler):
         records = ''
         error = ''
         
-        status_code = 201
+        status_code = 200
         internal_status = results[0]
         data = results[1]  
         
@@ -152,28 +143,62 @@ class Postgres_Handler(Sql_Handler):
         } 
         
         
-    #Insert command
     #This needs to be looked at, likely there are only certain fields that will be passed and the rest will be created either in lambda or S3/postgresql
-    #TODO - Potentially set for specific keywords instead of kwargs dict
-    def insert_data(self, **kwargs):
+    def insert_row(self, **kwargs):
+        #Key to get table_name argument
+        table_name_key = 'table_name'
+        
+        #Values dictioniary for sql parameters
+        values_dict = []
+        
         #Empty strings for column names and column values to be added
-        column_names = ''
-        column_values = ''
+        column_names_string = ''
+        column_values_string = ''
+        
+        #checks for the table name in args
+        if table_name_key not in kwargs:
+            assert("Error: table_name required as argument")
+        table_name = kwargs[table_name_key]
         
         #Begining of the SQL query
-        query_start = 'INSERT INTO "MetaData"'
+        query_start = 'INSERT INTO %(table_name)s'
+        values_dict[table_name_key] = table_name
         
         #Iterates through the arguments adds the key to the column_name, and the value to the column_value
         for key, value in kwargs.items():
-            column_names += f'"{key}"'
-            column_values += f"'{value}'"
+            column_names_string += f'{key}s'
+            column_values_string += f"%({key})s,"
+            values_dict[key] = value
+            
+        column_names = column_names_string[:-1]
+        column_values = column_values_string[:-1]
         
         #Builds the final SQL query for updating values
         query = f'{query_start}({column_names}) VALUES({column_values})'
         
         #Runs the command
-        results = self.__run_query(query)
-        return results
+        results = self.__run_query(query, values_dict)
+        return self.__format_insert_results(results)
+        
+    def __format_insert_results(self, results):
+        internal_status = results[0]
+        message = results[1]  if internal_status != -1 else ''
+        error = results[1] if internal_status == -1  else ''
+        status_code = 200 if internal_status != -1 else 400
+                
+        return {
+            'statusCode': status_code,
+            'headers': {
+                'Content-Type': "application/json",
+                'Access-Control-Allow-Headers': 'Content-Type',
+                'Access-Control-Allow-Origin': '*',
+                'Access-Control-Allow-Methods': 'OPTIONS,POST,GET',
+            },
+            "body": json.dumps({
+                'results': f'{message}',
+                'error' : f'{error}'
+            })
+        } 
         
     #Method to update a SQL row
     def update_row(self, **kwargs):
